<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 10:05:48 AM
 * @version $Rev$
 */

/**
 * Admin_Settings class
 * Used to ....
 */
class Admin_FormsSettings extends WP_Page {

    protected $interfacer = null;

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

    public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_formssettings_page';
    }

    public function getMenuTitle() {
        return 'Settings';
    }

    public function getPageTitle() {
        return 'Settings';
    }

    public function page() {
        $input_data = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);

        $agreement = Environment_Settings::getFormGeneralAgreement();
        $agreement_label = Environment_Settings::getFormGeneralAgreementLabel();
        $agreement_url = Environment_Settings::getFormGeneralAgreementUrl();

        $address_format = Environment_Settings::getFormAddressFormatGeneral();
        $apply_mode_status = Environment_Settings::getFormApplyOptionsStatus();
        $login_status = Environment_Settings::getLoginLinkStatus();
        $apply_captcha = Environment_Settings::getApplyFormCaptchaStatus();
        $taf_captcha = Environment_Settings::getTAFCaptchaStatus();
        $jas_captcha = Environment_Settings::getJASCaptchaStatus();
        $age_limit = Environment_Settings::getAgeLimit();
        $gender_unknown = Environment_Settings::getFormGenderUnknown();
        $jobboard_form = Environment_Settings::getSelectedFormForJobboard();
        if (!$jobboard_form) {
            $default_form = Environment_Installation::getDefaultForm();
            $jobboard_form = $default_form['id'];
        }


        $formsTable = new WP_Table(Environment_Installation::TABLE_FORMS);
        $available_forms = $formsTable->getByType(WP_Constants::ENTITY_TYPE_FORM_APPLY);

        if (isset($input_data['agreement'])) {
            $agreement = $input_data['agreement'];
        }

        if (isset($input_data['agreement_label'])) {
            $agreement_label = $input_data['agreement_label'];
        }

        if (isset($input_data['agreement_url'])) {
            $agreement_url = $input_data['agreement_url'];
        }

        if (isset($input_data['age_limit'])) {
            $age_limit = $input_data['age_limit'];
        }

        if ($input_data != null && wp_verify_nonce($input_data['_carerix_nonce_field'], 'settings')) {
            if (!isset($input_data['clear_data_nodes'])) {
                $address_format = @$input_data['address_format'];
                if (!is_string($address_format)) {
                    $address_format = '';
                }
                if (!is_string($agreement)) {
                    $address_format = '';
                }
                if (!is_string($agreement_label)) {
                    $agreement_label = '';
                }
                if (!is_string($agreement_url)) {
                    $agreement_url = '';
                }
                if (!is_string($age_limit)) {
                    $age_limit = '';
                }
                Environment_Settings::setFormAddressFormatGeneral($address_format);
                Environment_Settings::setFormGeneralAgreement($agreement);
                Environment_Settings::setFormGeneralAgreementLabel($agreement_label);
                Environment_Settings::setFormGeneralAgreementUrl($agreement_url);
                Environment_Settings::setAgeLimit($age_limit);

                if (isset($input_data['extra_apply'])) {
                    $apply_mode_status = 'on';
                    Environment_Settings::setFormApplyOptionsStatus($apply_mode_status);
                } else {
                    $apply_mode_status = 'off';
                    Environment_Settings::setFormApplyOptionsStatus($apply_mode_status);
                }

                if (isset($input_data['remove_login'])) {
                    $login_status = $input_data['remove_login'];
                    Environment_Settings::setLoginLinkStatus($login_status);
                } else {
                    $login_status = 'off';
                    Environment_Settings::setLoginLinkStatus($login_status);
                }

                $apply_captcha = 'off';
                if (isset($input_data['apply_captcha'])) {
                    $apply_captcha = 'on';
                }
                Environment_Settings::setApplyFormCaptchaStatus($apply_captcha);

                $taf_captcha = 'off';
                if (isset($input_data['taf_captcha'])) {
                    $taf_captcha = 'on';
                }
                Environment_Settings::setTAFCaptchaStatus($taf_captcha);

                $jas_captcha = 'off';
                if (isset($input_data['jas_captcha'])) {
                    $jas_captcha = 'on';
                }
                Environment_Settings::setJASCaptchaStatus($jas_captcha);

                $gender_unknown = 'off';
                if (isset($input_data['gender_unknown'])) {
                    $gender_unknown = 'on';
                }
                Environment_Settings::setFormGenderUnknown($gender_unknown);

                $jobboard_form = '';
                if (isset($input_data['jobboard_form'])) {
                    $jobboard_form = $input_data['jobboard_form'];
                } else {
                    $default_form = Environment_Installation::getDefaultForm();
                    $jobboard_form = $default_form['id'];
                }
                Environment_Settings::setSelectedFormForJobboard($jobboard_form);

            } else if (isset($input_data['clear_data_nodes'])) {
                Utils_Cache::cleanEnvironment();
            }
        }
        $data = array(
            'agreement' => $agreement,
            'agreement_label' => $agreement_label,
            'agreement_url' => $agreement_url,
            'address_format' => $address_format,
            'apply_mode_status' => $apply_mode_status,
            'remove_login' => $login_status,
            'apply_captcha' => $apply_captcha,
            'taf_captcha' => $taf_captcha,
            'jas_captcha' => $jas_captcha,
            'age_limit' => $age_limit,
            'gender_unknown' => $gender_unknown,
            'available_forms' => $available_forms,
            'selected_form' => $jobboard_form
        );

        $template = new Utils_Template('admin/forms/general_settings');
        $template->with($data)->display();
    }

}
